==> create-fly-1.21.10-6.0.8-4-sources.jar: com/zurrtum/create/infrastructure/packet/c2s/FilterScreenPacket.java <==
package com.zurrtum.create.infrastructure.packet.c2s;

import com.zurrtum.create.AllHandle;
import com.zurrtum.create.AllPackets;
import com.zurrtum.create.catnip.codecs.stream.CatnipStreamCodecBuilders;
import io.netty.buffer.ByteBuf;
import org.jetbrains.annotations.Nullable;

import java.util.function.BiConsumer;
import net.minecraft.class_2487;
import net.minecraft.class_3244;
import net.minecraft.class_9129;
import net.minecraft.class_9135;
import net.minecraft.class_9139;
import net.minecraft.class_9145;

public record FilterScreenPacket(Option option, @Nullable class_2487 data) implements C2SPacket {
    public static final class_9139<class_9129, FilterScreenPacket> CODEC = class_9139.method_56435(
        Option.STREAM_CODEC,
        FilterScreenPacket::option,
        CatnipStreamCodecBuilders.nullable(class_9135.field_48556),
        FilterScreenPacket::data,
        FilterScreenPacket::new
    );

    public FilterScreenPacket(Option option) {
        this(option, null);
    }

    @Override
    public class_9145<FilterScreenPacket> method_65080() {
        return AllPackets.CONFIGURE_FILTER;
    }

    @Override
    public BiConsumer<class_3244, FilterScreenPacket> callback() {
        return AllHandle::onFilterScreen;
    }

    public enum Option {
        WHITELIST,
        WHITELIST2,
        BLACKLIST,
        RESPECT_DATA,
        IGNORE_DATA,
        UPDATE_FILTER_ITEM,
        ADD_TAG,
        ADD_INVERTED_TAG,
        UPDATE_ADDRESS;

        public static final class_9139<ByteBuf, Option> STREAM_CODEC = CatnipStreamCodecBuilders.ofEnum(Option.class);
    }
}

==> create-fly-1.21.10-6.0.8-5-sources.jar: com/zurrtum/create/infrastructure/packet/c2s/FilterScreenPacket.java <==
package com.zurrtum.create.infrastructure.packet.c2s;

import com.zurrtum.create.AllHandle;
import com.zurrtum.create.AllPackets;
import com.zurrtum.create.catnip.codecs.stream.CatnipStreamCodecBuilders;
import io.netty.buffer.ByteBuf;
import net.minecraft.class_2487;
import net.minecraft.class_2596;
import net.minecraft.class_2792;
import net.minecraft.class_3244;
import net.minecraft.class_9129;
import net.minecraft.class_9135;
import net.minecraft.class_9139;
import net.minecraft.class_9145;
import org.jetbrains.annotations.Nullable;

public record FilterScreenPacket(Option option, @Nullable class_2487 data) implements class_2596<class_2792> {
    public static final class_9139<class_9129, FilterScreenPacket> CODEC = class_9139.method_56435(
        Option.STREAM_CODEC,
        FilterScreenPacket::option,
        CatnipStreamCodecBuilders.nullable(class_9135.field_48556),
        FilterScreenPacket::data,
        FilterScreenPacket::new
    );

    public FilterScreenPacket(Option option) {
        this(option, null);
    }

    @Override
    public void apply(class_2792 listener) {
        AllHandle.onFilterScreen((class_3244) listener, this);
    }

    @Override
    public class_9145<FilterScreenPacket> method_65080() {
        return AllPackets.CONFIGURE_FILTER;
    }

    public enum Option {
        WHITELIST,
        WHITELIST2,
        BLACKLIST,
        RESPECT_DATA,
        IGNORE_DATA,
        UPDATE_FILTER_ITEM,
        ADD_TAG,
        ADD_INVERTED_TAG,
        UPDATE_ADDRESS;

        public static final class_9139<ByteBuf, Option> STREAM_CODEC = CatnipStreamCodecBuilders.ofEnum(Option.class);
    }
}
